@@ -35,10 +35,8 @@
 #' should be run to retrieve any new or update trial records since
 #' this query was run the last time.
 #' This parameter takes precedence over \code{queryterm}.
-#' For "EUCTR", updates are available only for the last seven days;
-#' the query is run again if more time has passed since it was
-#' run last.
-#' Does not work with "CTIS" at this time.
+#' For "EUCTR" and "CTIS", updates are available only for the last seven days;
+#' the query is run again if more time has passed since it was run last.
 #'
 #' @param forcetoupdate If \code{TRUE}, run again the query
 #' given in \code{querytoupdate}, irrespective of when it was
@@ -113,8 +111,8 @@
 #'
 #' @inheritParams ctrDb
 #'
-#' @param verbose Printing additional information if set to
-#' \code{TRUE}; default is \code{FALSE}.
+#' @param verbose If \code{TRUE}, prints additional information
+#' (default \code{FALSE}).
 #'
 #' @param ... Do not use (capture deprecated parameters).
 #'
@@ -184,7 +182,7 @@ ctrLoadQueryIntoDb <- function(
     euctrresults = FALSE,
     euctrresultshistory = FALSE,
     ctgov2history = FALSE,
-    ctishistory = TRUE, # TODO
+    ctishistory = FALSE,
     documents.path = NULL,
     documents.regexp = "prot|sample|statist|sap_|p1ar|p2ars|icf|ctalett|lay|^[0-9]+ ",
     annotation.text = "",
